@@ -1,7 +1,7 @@
 import logging
 import threading
-from astropy.io import fits
 
+from pyobs.images import Image
 from .sbigfiltercamera import SbigFilterCamera
 
 
@@ -10,8 +10,9 @@ log = logging.getLogger(__name__)
 
 class Sbig6303eCamera(SbigFilterCamera):
     """A pyobs module for SBIG6303e cameras."""
+    __module__ = 'pyobs_sbig'
 
-    def _expose(self, exposure_time: int, open_shutter: bool, abort_event: threading.Event) -> fits.PrimaryHDU:
+    def _expose(self, exposure_time: float, open_shutter: bool, abort_event: threading.Event) -> Image:
         """Actually do the exposure, should be implemented by derived classes.
 
         Args:
@@ -27,17 +28,17 @@ class Sbig6303eCamera(SbigFilterCamera):
         """
 
         # do expsure
-        hdu = SbigFilterCamera._expose(self, exposure_time, open_shutter, abort_event)
+        img = SbigFilterCamera._expose(self, exposure_time, open_shutter, abort_event)
 
         # get binning
         xbin, ybin = self.get_binning()
 
         # gain is different in binned images
         gain = (1.4, 'Detector gain [e-/ADU]') if xbin == ybin == 1 else (2.3, 'Detector gain [e-/ADU]')
-        hdu.header['DET-GAIN'] = gain
+        img.header['DET-GAIN'] = gain
 
         # finished
-        return hdu
+        return img
 
 
 __all__ = ['Sbig6303eCamera']
