@@ -1,13 +1,16 @@
 import logging
-from astropy.io import fits
-from pyobs.mixins import MotionStatusMixin
+import threading
+from typing import List, Optional, Any
 
+from pyobs.images import Image
+from pyobs.mixins import MotionStatusMixin
 from pyobs.events import FilterChangedEvent
-from pyobs.interfaces import IFilters, IMotion
+from pyobs.interfaces import IFilters
+from pyobs.utils.enums import MotionStatus
 from pyobs.utils.threads import LockWithAbort
 
 from .sbigcamera import SbigCamera
-from .sbigudrv import *
+from .sbigudrv import FilterWheelPosition, FilterWheelStatus, FilterWheelModel
 
 
 log = logging.getLogger(__name__)
@@ -15,18 +18,15 @@ log = logging.getLogger(__name__)
 
 class SbigFilterCamera(MotionStatusMixin, SbigCamera, IFilters):
     """A pyobs module for SBIG cameras."""
+    __module__ = 'pyobs_sbig'
 
-    def __init__(self, filter_wheel: str = 'UNKNOWN', filter_names: list = None, *args, **kwargs):
+    def __init__(self, filter_wheel: str, filter_names: Optional[List[str]] = None, **kwargs: Any):
         """Initializes a new SbigCamera.
 
         Args:
-            filter_wheel: Name of filter wheel used by the camera.
             filter_names: List of filter names.
         """
-        SbigCamera.__init__(self, *args, **kwargs)
-
-        # filter wheel
-        self._filter_wheel = FilterWheelModel[filter_wheel]
+        SbigCamera.__init__(self, **kwargs, driver_kwargs=dict(filter_wheel=filter_wheel))
 
         # and filter names
         if filter_names is None:
@@ -43,35 +43,27 @@ class SbigFilterCamera(MotionStatusMixin, SbigCamera, IFilters):
         self._position = FilterWheelPosition.UNKNOWN
 
         # init mixins
-        MotionStatusMixin.__init__(self, *args, **kwargs, motion_status_interfaces=['IFilters'])
+        MotionStatusMixin.__init__(self, **kwargs, motion_status_interfaces=['IFilters'])
 
-    def open(self):
+    def open(self) -> None:
         """Open module.
 
         Raises:
             ValueError: If cannot connect to camera or set filter wheel.
         """
 
-        # set filter wheel model
-        if self._filter_wheel != FilterWheelModel.UNKNOWN:
-            log.info('Initialising filter wheel...')
-            try:
-                self._cam.set_filter_wheel(self._filter_wheel)
-            except ValueError as e:
-                raise ValueError('Could not set filter wheel: %s' % str(e))
-
         # open camera
         SbigCamera.open(self)
 
         # init status of filter wheel
-        if self._filter_wheel != FilterWheelModel.UNKNOWN:
-            self._change_motion_status(IMotion.Status.POSITIONED, interface='IFilters')
+        if self._driver.filter_wheel != FilterWheelModel.UNKNOWN:
+            self._change_motion_status(MotionStatus.POSITIONED, interface='IFilters')
 
         # subscribe to events
         if self.comm:
             self.comm.register_event(FilterChangedEvent)
 
-    def _expose(self, exposure_time: int, open_shutter: bool, abort_event: threading.Event) -> fits.PrimaryHDU:
+    def _expose(self, exposure_time: float, open_shutter: bool, abort_event: threading.Event) -> Image:
         """Actually do the exposure, should be implemented by derived classes.
 
         Args:
@@ -87,16 +79,16 @@ class SbigFilterCamera(MotionStatusMixin, SbigCamera, IFilters):
         """
 
         # do expsure
-        hdu = SbigCamera._expose(self, exposure_time, open_shutter, abort_event)
+        img = SbigCamera._expose(self, exposure_time, open_shutter, abort_event)
 
         # add filter to FITS headers
-        if self._filter_wheel != FilterWheelModel.UNKNOWN:
-            hdu.header['FILTER'] = (self.get_filter(), 'Current filter')
+        if self._driver.filter_wheel != FilterWheelModel.UNKNOWN:
+            img.header['FILTER'] = (self.get_filter(), 'Current filter')
 
         # finished
-        return hdu
+        return img
 
-    def set_filter(self, filter_name: str, *args, **kwargs):
+    def set_filter(self, filter_name: str, **kwargs: Any) -> None:
         """Set the current filter.
 
         Args:
@@ -108,7 +100,7 @@ class SbigFilterCamera(MotionStatusMixin, SbigCamera, IFilters):
         """
 
         # do we have a filter wheel?
-        if self._filter_wheel == FilterWheelModel.UNKNOWN:
+        if self._driver.filter_wheel == FilterWheelModel.UNKNOWN:
             raise NotImplementedError
 
         # reverse dict and search for name
@@ -117,24 +109,24 @@ class SbigFilterCamera(MotionStatusMixin, SbigCamera, IFilters):
             raise ValueError('Unknown filter: %s' % filter_name)
 
         # there already?
-        position, status = self._cam.get_filter_position_and_status()
+        position, status = self._driver.camera.get_filter_position_and_status()
         if position == filters[filter_name] and status == FilterWheelStatus.IDLE:
             log.info('Filter changed.')
             return
 
         # set status
-        self._change_motion_status(IMotion.Status.SLEWING, interface='IFilters')
+        self._change_motion_status(MotionStatus.SLEWING, interface='IFilters')
 
         # acquire lock
         with LockWithAbort(self._lock_motion, self._abort_motion):
             # set it
             log.info('Changing filter to %s...', filter_name)
-            self._cam.set_filter(filters[filter_name])
+            self._driver.camera.set_filter(filters[filter_name])
 
             # wait for it
             while True:
                 # break, if wheel is idle and filter is set
-                position, status = self._cam.get_filter_position_and_status()
+                position, status = self._driver.camera.get_filter_position_and_status()
                 if position == filters[filter_name] and status == FilterWheelStatus.IDLE:
                     break
 
@@ -148,9 +140,9 @@ class SbigFilterCamera(MotionStatusMixin, SbigCamera, IFilters):
             self.comm.send_event(FilterChangedEvent(filter_name))
 
         # set status
-        self._change_motion_status(IMotion.Status.POSITIONED, interface='IFilters')
+        self._change_motion_status(MotionStatus.POSITIONED, interface='IFilters')
 
-    def get_filter(self, *args, **kwargs) -> str:
+    def get_filter(self, **kwargs: Any) -> str:
         """Get currently set filter.
 
         Returns:
@@ -162,17 +154,17 @@ class SbigFilterCamera(MotionStatusMixin, SbigCamera, IFilters):
         """
 
         # do we have a filter wheel?
-        if self._filter_wheel == FilterWheelModel.UNKNOWN:
+        if self._driver.filter_wheel == FilterWheelModel.UNKNOWN:
             raise NotImplementedError
 
         try:
-            self._position, _ = self._cam.get_filter_position_and_status()
+            self._position, _ = self._driver.camera.get_filter_position_and_status()
         except ValueError:
             # use existing position
             pass
         return self._filter_names[self._position]
 
-    def list_filters(self, *args, **kwargs) -> list:
+    def list_filters(self, **kwargs: Any) -> List[str]:
         """List available filters.
 
         Returns:
@@ -183,7 +175,7 @@ class SbigFilterCamera(MotionStatusMixin, SbigCamera, IFilters):
         """
 
         # do we have a filter wheel?
-        if self._filter_wheel == FilterWheelModel.UNKNOWN:
+        if self._driver.filter_wheel == FilterWheelModel.UNKNOWN:
             raise NotImplementedError
 
         # return names
